<?php
/*
Plugin Name: Covert Copy Traffic Pro
Description: This plugin allows you to automatically insert links and text when people copy and paste or scrape your blog content. This is the Pro version with loads of extra features including the ability to use the plugin outside of WordPress. Remember to deactivate the basic version before using this Pro version.
Version: 2.3
Author: IM Wealth Builders Ltd
Author URI: http://imwealthbuilders.com/newplugins

Copyright 2018  IM Wealth Builders

*/

define('IMWB_CPY_PRO_VERSION', '2.3');
define('IMWB_CPY_PRO_FOLDER', 'covertcopytraffic-pro');
define('IMWB_CPY_PRO_PREFIX', 'imwb_');

/**
 * This is where you add comments for your plugin class
 * @author John Merrick
 */
class IMWB_Covert_Copy_PRO {
	/**
	 * This value will be used for
	 * - the gettext textdomain
	 * - the subfolder when adding scripts and styles
	 * - the handle for scripts and styles
	 * Please make sure that this value corresponds to the folder name where your plugin resides.
	 * @var string
	 */
	 var $plugin_name = "";
	 var $plugin_url = "";
	 var $plugin_path = "";
	 var $update;

	/**
	 * The constructor is executed when the class is instantiated and the plugin gets loaded.
	 * @return void
	 */
	function __construct() {

	   $this->plugin_name = IMWB_CPY_PRO_PREFIX.IMWB_CPY_PRO_FOLDER;
	   $this->plugin_path = plugin_dir_path(__FILE__);

   	// Hack to avoid firing on Admin Login or Registration page
   	if ( in_array( $GLOBALS['pagenow'], array( 'wp-login.php', 'wp-register.php' ) ) )
   	   return;

   	$this->plugin_url = plugins_url(basename( dirname( __FILE__)));

      if(is_admin()){
         // Get Update Information
      	$this->get_update_info();
      	add_action('admin_menu', array(&$this,'init_admin_menu'));
      }
      else {
      	add_action('wp_print_scripts', array(&$this, 'init_scripts'),20);

      	if (get_option('rss_use_excerpt'))
            add_filter( "the_excerpt_rss", array(&$this, 'content_feed'),20,2);
         else
         	add_filter( "the_content_feed", array(&$this, 'content_feed'),20,2);
      }

	}

	//Returns an array of admin options
	function get_admin_options() {
		$adminOptions = array('aText' => 'Read More',
		                      'aURL' => 'P',
		                      'aURLCustom' => '',
		                      'aPlace' => 'B',
		                      'aMinWords' => '10',
		                      'aIncLink' => 'Y',
		                      'aIncMsg' => 'Y',
		                      'aMsgText' => '',
		                      'aMsgPlace' => 'A',
		                      'sfShow' => 'Y',
		                      'sfAnchorType' => 'S',
  		                      'sfAnchorTxt' => '',
		                      'aText' => 'Read More',
                            'ssaURL' => 'P',
                            'ssaURLCustom' => '',
                            'ssaPlace' => 'B',
                            'ssaMinWords' => '10',
                            'ssaIncLink' => 'Y',
                            'ssaIncMsg' => 'Y',
                            'ssaMsgText' => '',
                            'ssaMsgPlace' => 'A');

		$devOptions = get_option($this->plugin_name."-AdminOptions");
		if (!empty($devOptions)) {
			foreach ($devOptions as $key => $option)
				$adminOptions[$key] = $option;
		}
		update_option($this->plugin_name."-AdminOptions", $adminOptions);
		return $adminOptions;
	}

	/**
	 * Loading the frontend javascripts
	 * /scripts/script.js from the plugin directory. By default the script is enqueued
	 * in the page footer for faster page loading.
	 * @return void
	 */
	function init_scripts() {
   	$devOptions = $this->get_admin_options();

		// Only enqueue scripts on frontend.
		wp_enqueue_script('jquery');
      wp_enqueue_script($this->plugin_name . '-script', $this->plugin_url.'/scripts/script.js', array('jquery'), IMWB_CPY_PRO_VERSION);

      $aText = stripslashes($this->get_attribution_msg());

    	wp_localize_script( $this->plugin_name . '-script', 'IMWB_CPY_Options', array( 'aText' => $aText, 'aPlace' => $devOptions['aPlace'], 'aMinWords' =>  $devOptions['aMinWords']) );
	}

	function get_attribution_msg($feed = false, $sfAText = '') {
      $devOptions = $this->get_admin_options();

	   $aText = '';
   	$aURL = '';

   	switch($devOptions['aURL']) {
   	   case 'P': if($feed)
   	                $aURL = get_permalink();
   	             else
   	                $aURL =  (is_ssl() ? "https://" : "http://") . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'];
   	             break;
   	   case 'H': $aURL = home_url();
   	             break;
   	   case 'C': $aURL = $devOptions['aURLCustom'];
   	             break;
   	}

   	if(!$feed && !empty($aURL))
      	$aURL = "<a href='".$aURL."'>".$aURL."</a>";

   	$aText = $devOptions['aIncLink'] == 'Y' ? $devOptions['aText'].' '.$aURL : "";

   	// Place Attribution Message
   	if(trim($devOptions['aMsgText']) != '' && $devOptions['aIncMsg'] == 'Y') {

   	   if($feed)
      	   $aMsgText = str_replace('{A_LINK}', '<a href="'.$aURL.'">'.$sfAText.'</a>', $devOptions['aMsgText']);
   	   else
      	   $aMsgText = str_replace('{A_LINK}', esc_attr($devOptions['aText']).' '.$aURL, $devOptions['aMsgText']);
   	   $aMsgText = str_replace('{SITE_TITLE}', get_bloginfo('name'), $aMsgText);
   	   $aMsgText = str_replace('{TAGLINE}', get_bloginfo('description'), $aMsgText);
   	   $aMsgText = str_replace('{DATE}', date(get_option('date_format')), $aMsgText);
   	   $aMsgText = str_replace('{TIME}', date(get_option('time_format')), $aMsgText);

   	   $aMsgText = $this->sanitize_msg($aMsgText);
   	   if(!empty($aText) && $devOptions['aMsgPlace'] == 'A')
   	      $aText = $aMsgText.'<br>'.$aText;
   	   else if(!empty($aText) && $devOptions['aMsgPlace'] == 'B')
   	      $aText = $aText.'<br>'.$aMsgText;
   	   else
   	      $aText = $aMsgText;
   	}

   	return $aText;

	}

	function sanitize_msg($text) {

      $text = do_shortcode($text);
	   $text = preg_replace("/(\r\n|\r|\n)/", "<br>", $text);
	   $text = addslashes_gpc(stripslashes($text));

	   return $text;
	}

	/**
	 * Loading the stylesheet for this plugin.
	 * @return void
	 */
	function init_styles() {
      wp_enqueue_style($this->plugin_name . '-stylesheet', $this->plugin_url.'/styles/admin_options_page.css', array(), '1.2', 'all');
	}

	/**
	 * Adds a new menu with the name "My Admin Menu" and let's anyone that
	 * can publish posts be able to use it.
	 * @return void
	 */
	function init_admin_menu() {
		// Add the menu page
      $hook_name = add_menu_page( 'Covert Copy Traffic Pro Admin Menu',
          'Covert Copy Traffic PRO',
          'manage_options',
          $this->plugin_name . '-admin-menu',
          array(&$this, 'load_settings_page'),
          'dashicons-editor-paste-text');

      add_action('admin_print_styles-' . $hook_name, array(&$this, 'init_styles'));

  	   $hook_name = add_submenu_page($this->plugin_name . '-admin-menu', 'Covert Copy Traffic Settings', 'Settings', 'manage_options', $this->plugin_name . '-admin-menu', array(&$this, 'load_settings_page'));

  	   add_action('admin_print_styles-' . $hook_name, array(&$this, 'init_styles'));

 		$hook_name = add_submenu_page($this->plugin_name . '-admin-menu', 'Covert Copy Traffic - Standalone Script', 'Standalone Script', 'manage_options', $this->plugin_name . '-admin-menu-1', array(&$this, 'load_script_page'));

 		add_action('admin_print_styles-' . $hook_name, array(&$this, 'init_styles'));

	}

	/**
	 * This function will be executed when the admin page is to be loaded
	 * @return void
	 */
	function load_settings_page() {
		$devOptions = $this->get_admin_options();
		// Include the HTML from a separate file to keep the plugin class clean
		require "pages/admin_options_page.php";
	}

   /**
    * This function will be executed when the script page is to be loaded
    * @return void
    */
   function load_script_page() {
   	$devOptions = $this->get_admin_options();
   	// Include the HTML from a separate file to keep the plugin class clean
   	require "pages/script_options_page.php";
   }

	function content_feed($content, $feed_type = null) {
		$devOptions = $this->get_admin_options();

      if($devOptions['sfShow'] != 'Y')
         return $content;

      $sfAText = "";

      switch($devOptions['sfAnchorType']) {
         case 'C': $sfAText = $devOptions['sfAnchorTxt'];
                   break;
         case 'S': $sfAText = get_bloginfo();
                   break;
         case 'T': $sfAText = get_the_title();
                   break;
      }

      $aText = stripslashes($this->get_attribution_msg(true, $sfAText));

      if(empty($aText)) return $content;

  	   $content = $content.'<br><br>'.$aText;

	   return $content;
	}

	function get_wp_root_path()
	{
	    $path = parse_url(get_bloginfo('wpurl'), PHP_URL_PATH);
	    if(!isset($path))
	       return '/';
	    else
	  	    return $path;
	}

   function get_update_info() {
      // Include Update Class
      require_once('imwb-plugin-update-checker-no-lic.php');
      $gdd21ed = __FILE__;

      $this->update=new ImwbPluginUpdateChecker_nolic($gdd21ed,'covertcopytraffic-pro','plugin-update');
   }

}

/**
 * Register the plugin
 * @todo Change 'Plugin_Boilerplate' in the anonymous function to the name of the class
 */

 /**
 * Register the plugin
 */
$IMWBCovertCopyPRO = null;

function run_covert_copy_pro() {
  global $IMWBCovertCopyPRO;
	$IMWBCovertCopyPRO = new IMWB_Covert_Copy_PRO();
}
run_covert_copy_pro();

function imwb_cpyp_admin_notice(){
   if (is_plugin_active('covertcopytraffic/covertcopy-plugin.php')) {
   echo "<div id='update-nag' class='update-nag'><strong>Covert Copy Traffic PRO</strong> You must deactivate the standard version of Covert Copy Traffic</div>";
   }
}

add_action('admin_notices', 'imwb_cpyp_admin_notice');
